@@ -22,12 +22,14 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
                                   path = ".", force = FALSE,
                                   code_files = character(), cpp_files = character(),
                                   example_code = TRUE, attributes = TRUE, module = FALSE,
-                                  author = "Who wrote it",
-                                  maintainer = if (missing(author)) "Who to complain to"
+                                  author = "Your Name",
+                                  maintainer = if (missing(author)) "Your Name"
                                                else author,
-                                  email = "yourfault@somewhere.net",
-                                  license = "What Licence is it under ?") {
+                                  email = "your@email.com",
+                                  license = "GPL (>= 2)") {
   
+    havePkgKitten <- require("pkgKitten", quietly=TRUE, character.only=TRUE)
+
     call <- match.call()
     call[[1]] <- as.name("package.skeleton")
     env <- parent.frame(1)
@@ -42,7 +44,7 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
 			assign("rcpp_hello_world", function() {}, envir = env)
 			remove_hello_world <- TRUE
 		} else {
-	    remove_hello_world <- FALSE
+            remove_hello_world <- FALSE
 		}
 	} else {
         if (example_code && !isTRUE(attributes)) {
@@ -85,10 +87,6 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
 		x <- cbind(read.dcf(DESCRIPTION),
                    "Imports" = paste(imports, collapse = ", "),
                    "LinkingTo" = "Rcpp")
-		if (isTRUE(module)) {
-		    x <- cbind(x, "RcppModules" = "yada, stdVector, NumEx")
-		    message(" >> added RcppModules: yada, stdVector, NumEx")
-		}
 		x[, "Author"] <- author
 		x[, "Maintainer"] <- sprintf("%s <%s>", maintainer, email)
 		x[, "License"] <- license
@@ -108,26 +106,30 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
         message(" >> added useDynLib directive to NAMESPACE" )
     }
     if (isTRUE(module)) {
-        writeLines('import(methods)', ns)
-        writeLines('importFrom(Rcpp, loadModule)', ns)
-        message(" >> added importFrom(Rcpp, loadModule) directive to NAMESPACE")
+        writeLines('import(methods, Rcpp)', ns)
+        message(" >> added import(methods, Rcpp) directive to NAMESPACE")
+    } else {
+        writeLines('importFrom(Rcpp, evalCpp)', ns)
+        message(" >> added importFrom(Rcpp, evalCpp) directive to NAMESPACE" )
     }
-    writeLines('importFrom(Rcpp, evalCpp)', ns)
-    message(" >> added importFrom(Rcpp, evalCpp) directive to NAMESPACE" )
     close( ns )
 
 	## update the package description help page
-	package_help_page <- file.path(root, "man", sprintf( "%s-package.Rd", name))
-	if (file.exists(package_help_page)) {
-	    lines <- readLines(package_help_page)
-	    lines <- gsub("What license is it under?", license, lines, fixed = TRUE)
-	    lines <- gsub("Who to complain to <yourfault@somewhere.net>",
-                      sprintf( "%s <%s>", maintainer, email),
-                      lines, fixed = TRUE)
-	    lines <- gsub( "Who wrote it", author, lines, fixed = TRUE)
-	    writeLines(lines, package_help_page)
-	}
-
+    if (havePkgKitten) {                # if pkgKitten is available, use it
+        pkgKitten::playWithPerPackageHelpPage(name, path, maintainer, email)
+    } else {
+        package_help_page <- file.path(root, "man", sprintf( "%s-package.Rd", name))
+        if (file.exists(package_help_page)) {
+            lines <- readLines(package_help_page)
+            lines <- gsub("What license is it under?", license, lines, fixed = TRUE)
+            lines <- gsub("Who to complain to <yourfault@somewhere.net>",
+                          sprintf( "%s <%s>", maintainer, email),
+                          lines, fixed = TRUE)
+            lines <- gsub( "Who wrote it", author, lines, fixed = TRUE)
+            writeLines(lines, package_help_page)
+        }
+    }
+    
 	## lay things out in the src directory
 	src <- file.path(root, "src")
 	if (!file.exists(src)) {
@@ -171,15 +173,17 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
 		message( " >> added Rd file for rcpp_hello_world")
 	}
 
-	if (isTRUE( module)) {
+	if (isTRUE(module)) {
 		file.copy(system.file("skeleton", "rcpp_module.cpp", package="Rcpp"),
                   file.path(root, "src"))
 		file.copy(system.file("skeleton", "Num.cpp", package="Rcpp"),
                   file.path(root, "src"))
 		file.copy(system.file("skeleton", "stdVector.cpp", package="Rcpp"),
                   file.path(root, "src"))
-		file.copy(system.file( "skeleton", "zzz.R", package ="Rcpp"),
+		file.copy(system.file("skeleton", "zzz.R", package ="Rcpp"),
                   file.path(root, "R"))
+		file.copy(system.file("skeleton", "Rcpp_modules_examples.Rd", package ="Rcpp"),
+                  file.path(root, "man"))
 		message(" >> copied the example module file ")
 	}
 
@@ -205,4 +209,3 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
 
 	invisible(NULL)
 }
-
