@@ -1,4 +1,4 @@
-# Copyright (C) 2009 - 2011 Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2009 - 2013 Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -20,12 +20,6 @@
 .classes_map <- new.env()
 
 .onLoad <- function(libname, pkgname){
-    minimum_svn_rev <- packageDescription( pkgname )[["MinimumSvnRev"]]
-    # if( as.integer(R.version[["svn rev"]]) < as.integer(minimum_svn_rev)){
-    #     packageStartupMessage(gettextf(paste("R version (%s) older than minimum required (%s)",
-    #                                          "for full use of reference methods"),
-    #                                    R.version[["svn rev"]], minimum_svn_rev))
-    # }
     new_dummyObject(.dummyInstancePointer);
 }
 
